{
  pkgs,
  systemConfig,
  ...
}:

{
  boot = {
    kernelPackages = pkgs.linuxKernel.packages.linux_rpi4;
    initrd.availableKernelModules = [
      "xhci_pci"
      "usbhid"
      "usb_storage"
    ];
    loader = {
      grub.enable = false;
      generic-extlinux-compatible.enable = true;
    };
  };

  fileSystems = {
    "/" = {
      device = "/dev/disk/by-label/NIXOS_SD";
      fsType = "ext4";
      options = [ "noatime" ];
    };
  };

  hardware.enableRedistributableFirmware = true;

  networking = {
    hostName = systemConfig.hostName;
    networkmanager.enable = true;
  };

  services.openssh.enable = true;

  programs.gnupg.agent = {
    enable = true;
    enableSSHSupport = true;
  };
  services.pcscd.enable = true;

  system.stateVersion = systemConfig.version;

  users = {
    mutableUsers = false;
    users.${systemConfig.user.name} = {
      isNormalUser = true;
      password = systemConfig.user.password;
      extraGroups = [ "wheel" ];
    };
  };
}
